@@ -44,8 +44,6 @@ void parseInputFile(_In_ const M_STRING_VIEW& parameter, CompilerParams& params,
         FixupFileName(inputFile);
         c_inputFile = utf8_encode(inputFile);
         params.set_inputFile(c_inputFile);
-#else  /* _WIN32 */
-        params.set_inputFile(inputFile);
 #endif /* _WIN32 */
         files.set_inputFile(inputFile);
         if (params.get_verbose()) {
@@ -133,9 +131,6 @@ void cmd_Fc(CompilerParams& params, Files& files, _In_ const M_STRING_VIEW& asse
 }
 
 void cmd_Fd(CompilerParams& params, Files& files, _In_ const M_STRING_VIEW& pdbFile) {
-#ifdef _WIN32
-    files.set_c_pdbFile(utf8_encode(pdbFile));
-#endif /* _WIN32 */
     files.set_pdbFile(pdbFile);
 
     UINT cmd = params.get_commands();
@@ -252,6 +247,18 @@ void cmd_Gpp(CompilerParams& params) {
     return;
 }
 
+void cmd_I(CompilerParams& params, _In_ const M_STRING_VIEW& _includeDir) {
+    if (params.get_verbose()) {
+#ifdef _WIN32
+        std::wcout << std::format(L"option -I (Shader Include Dir) with arg {}\n", _includeDir);
+#else
+        std::cout << std::format("option -I (Shader Include Dir) with arg {}\n", _includeDir);
+#endif
+    }
+    params.get_includeDirs()->AddIncludeDir(_includeDir);
+    return;
+}
+
 void cmd_Lx(CompilerParams& params) {
     if (params.get_verbose()) {
         std::cout << "option -Lx - output hexidecimal literals\n";
@@ -394,7 +401,7 @@ void cmd_T(CompilerParams& params, _In_ const M_STRING_VIEW& _model) {
 #ifdef _WIN32
     std::string model = utf8_encode(_model);
 #else
-    std::string model = { _model.data(), _model.size()};
+    std::string model = { _model.data(), _model.size() };
 #endif
     if (params.get_verbose()) {
         std::cout << std::format("option -T (Shader Model/Profile) with arg {}\n", model);
@@ -505,9 +512,9 @@ bool  parseCompilerOnlyCall(
         return false;
     }
 
-    for (int i = 0; i < COMPILER_ONLY_ENTRIES_LENGTH; i++) {
-        if (argument.compare(arg_idx, g_CompilerOnlyCall[i].Param.size(), g_CompilerOnlyCall[i].Param) == 0) {
-            auto ptr = (gCompilerp*)g_CompilerOnlyCall[i].method;
+    for (CompilerOnlyEntry currentEntry : g_CompilerOnlyCall) {
+        if (argument.compare(arg_idx, currentEntry.Param.size(), currentEntry.Param) == 0) {
+            auto ptr = (gCompilerp*)currentEntry.method;
             ptr(params);
             *index += 1;
             return true;
@@ -541,18 +548,18 @@ bool parseCompilerFileCall(
         return false;
     }
 
-    for (size_t i = 0; i < COMPILER_FILE_ENTRIES_LENGTH; i++) {
-        if (argument.compare(arg_idx, g_CompilerFileCall[i].Param.size(), g_CompilerFileCall[i].Param) != 0) {
+    for (CompileFileEntry currentEntry : g_CompilerFileCall) {
+        if (argument.compare(arg_idx, currentEntry.Param.size(), currentEntry.Param) != 0) {
             continue;
         }
-        arg_idx += g_CompilerFileCall[i].Param.size();
+        arg_idx += currentEntry.Param.size();
         if (arg_idx >= argument.size()) {
             *index += 1;
             if (*index >= args.size()) {
 #ifdef _WIN32
-                std::wcerr << std::format(L"Error: missing required argument for option {}\n", g_CompilerFileCall[i].Param);
+                std::wcerr << std::format(L"Error: missing required argument for option {}\n", currentEntry.Param);
 #else
-                std::cerr << std::format("Error: missing required argument for option {}\n", g_CompilerFileCall[i].Param );
+                std::cerr << std::format("Error: missing required argument for option {}\n", currentEntry.Param );
 #endif
                 return false;
             }
@@ -561,7 +568,7 @@ bool parseCompilerFileCall(
         else {
             argumentOption = argument.substr(arg_idx, argument.size());
         }
-        auto ptr = (gCompilerFilep*)g_CompilerFileCall[i].method;
+        auto ptr = (gCompilerFilep*)currentEntry.method;
         ptr(params, files, argumentOption);
         *index += 1;
         return true;
@@ -587,8 +594,8 @@ bool parseIgnoredOptions(
     else {
         return false;
     }
-    for (int i = 0; i < IGNORED_OPTS_LENGTH; i++) {
-        if (argument.compare(arg_idx, std::string::npos, g_IgnoredOptions[i]) == 0) {
+    for (M_STRING CurrentEntry : g_IgnoredOptions) {
+        if (argument.compare(arg_idx, std::string::npos, CurrentEntry) == 0) {
             option_ignored(argument, params);
             return true;
         }
@@ -613,8 +620,8 @@ bool parseNotSupportedOptions(
     else {
         return false;
     }
-    for (int i = 0; i < NOT_SUPPORTED_LENGTH; i++) {
-        if (argument.compare(arg_idx, std::string::npos, g_NotSupportedArgs[i]) == 0) {
+    for (M_STRING CurrentEntry : g_NotSupportedArgs) {
+        if (argument.compare(arg_idx, std::string::npos, CurrentEntry) == 0) {
 #ifdef _WIN32
             std::wcerr << std::format(L"option -{} not supported", argument);
 #else
