@@ -12,9 +12,9 @@
 #include "efxc2Files.h"
 
 #ifdef _WIN32
-void CompilerTasks(Compiler& compiler, Files& files, CompilerParams& params) {
+void CompilerTasks(Compiler& compiler, Files& files, const CompilerParams& params) {
 #else
-void CompilerTasks(Compiler& compiler, Files& files, CompilerParams& params) {
+void CompilerTasks(Compiler& compiler, Files& files, const CompilerParams& params) {
 #endif
     compiler.Compile();
     compiler.StripShader();
@@ -22,7 +22,7 @@ void CompilerTasks(Compiler& compiler, Files& files, CompilerParams& params) {
         files.WriteIncludeFile(compiler,params);
     }
     if ((params.get_commands() & CMD_WRITE_PDB_FILE) == CMD_WRITE_PDB_FILE) {
-        files.WritePDBFile(compiler);
+        files.WritePDBFile(compiler, params);
     }
     if ((params.get_commands() & CMD_WRITE_OBJECT) == CMD_WRITE_OBJECT) {
         files.WriteObjectFile(compiler,params);
